/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

var SV = window.SV || {};

/** @param {jQuery} $ jQuery Object */
!function($, window, document, _undefined)
{
  "use strict";

  /**
   * An inserter that is triggered on input changes.
   *
   * The serialized input is passed to the passed link.
   */
  SV.InserterInput = XF.Element.newHandler({
    options: $.extend(true, {}, XF._baseInserterOptions),

    inserter: null,

    /**
     * Sets up inserter and event callbacks.
     */
    init: function()
    {
      this.inserter = new XF.Inserter(this.$target, this.options);
      this.$target.on('change', XF.proxy(this, 'change'));
    },

    /**
     * @param {Event} e
     */
    change: function(e)
    {
      var prepend = '?';
      if (this.options.href.indexOf('?') >= 0) {
        prepend = '&';
      }

      var params = prepend + $.param(this.$target);
      this.inserter.href = this.options.href + params;
      this.inserter.onEvent(e);
    }
  });

  // register handlers
  XF.Element.register('sv-inserter-input', 'SV.InserterInput');
}(jQuery, window, document);
