<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\Entity;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int user_id
 * @property string action_type
 * @property array action_names
 *
 * RELATIONS
 * @property \XF\Entity\User User
 */
class DefaultFilters extends Entity
{
    /**
     * @param Structure $structure
     *
     * @return Structure
     */
    public static function getStructure(Structure $structure)
    {
        $structure->table = 'modess_modlog_preferences';
        $structure->shortName = 'SV\ModeratorEssentials:DefaultFilters';
        $structure->primaryKey = 'user_id';
        $structure->columns = [
            'user_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'action_type' => [
                'type'    => self::STR,
                'default' => ''
            ],
            'action_names' => [
                'type'    => self::JSON_ARRAY,
                'default' => []
            ]
        ];
        $structure->getters = [];
        $structure->relations = [
            'User' => [
                'entity'     => 'XF:User',
                'type'       => self::TO_ONE,
                'conditions' => 'user_id',
                'primary'    => true
            ]
        ];

        return $structure;
    }
}
