<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\Entity;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int|null search_id
 * @property array search_results
 * @property int result_count
 * @property int user_id
 * @property int search_date
 * @property array search_params
 *
 * RELATIONS
 * @property \XF\Entity\User User
 */
class Search extends Entity
{
    /**
     * @param array $results
     *
     * @return bool
     */
    protected function verifySearchResults(&$results)
    {
        if (!is_array($results)) {
            $results = [];
        }

        $this->result_count = count($results);
        return true;
    }

    /**
     * @param array $filters
     *
     * @return bool
     */
    protected function verifySearchParams(&$filters)
    {
        if (!is_array($filters)) {
            $filters = [];
            return true;
        }

        ksort($filters);
        $filters = array_filter($filters);
        return true;
    }

    /**
     * @param Structure $structure
     *
     * @return Structure
     */
    public static function getStructure(Structure $structure)
    {
        $structure->table = 'modess_modlog_search';
        $structure->shortName = 'SV\ModeratorEssentials:Search';
        $structure->primaryKey = 'search_id';
        $structure->columns = [
            'search_id' => [
                'type'          => self::UINT,
                'autoIncrement' => true,
                'nullable'      => true
            ],
            'search_results' => [
                'type'     => self::JSON_ARRAY,
                'default'  => []
            ],
            'result_count' => [
                'type'    => self::UINT,
                'default' => 0
            ],
            'user_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'search_date' => [
                'type'    => self::UINT,
                'default' => \XF::$time
            ],
            'search_params' => [
                'type'    => self::JSON_ARRAY,
                'default' => []
            ]
        ];
        $structure->getters = [];
        $structure->relations = [
            'User' => [
                'entity'     => 'XF:User',
                'type'       => self::TO_ONE,
                'conditions' => 'user_id',
                'primary'    => true
            ]
        ];

        return $structure;
    }
}
