<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\Entity;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int|null discussion_id
 * @property int thread_id
 * @property int forum_id
 * @property int discussion_thread
 * @property int user_id
 * @property int content_user_id
 * @property string content_username
 *
 * RELATIONS
 * @property \XF\Entity\Thread Thread
 * @property \XF\Entity\Thread NotesThread
 */
class ThreadNotes extends Entity
{
    /**
     * @param string $error
     *
     * @return bool
     */
    public function canView(&$error = null)
    {
        /** @var \SV\ModeratorEssentials\XF\Entity\User $visitor */
        $visitor = \XF::visitor();
        if (!$visitor->canViewThreadNotes($error)) {
            return false;
        }

        return (
            $this->Thread->canView($error)
            && $this->NotesThread->canView($error)
        );
    }

    /**
     * Entity post-delete events.
     */
    protected function _postDelete()
    {
        if ($this->NotesThread) {
            $this->NotesThread->fastUpdate('discussion_type', '');
        }
    }

    /**
     * @param Structure $structure
     *
     * @return Structure
     */
    public static function getStructure(Structure $structure)
    {
        $visitor = \XF::visitor();

        $structure->table = 'xf_moderator_discussion';
        $structure->shortName = 'SV\ModeratorEssentials:ThreadNotes';
        $structure->primaryKey = 'discussion_id';
        $structure->columns = [
            'discussion_id' => [
                'type'          => self::UINT,
                'autoIncrement' => true,
                'nullable'      => true
            ],
            'thread_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'forum_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'discussion_thread' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'user_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'content_user_id' => [
                'type'     => self::UINT,
                'required' => true
            ],
            'content_username' => [
                'type'      => self::STR,
                'required'  => true,
                'maxLength' => 50
            ]
        ];
        $structure->getters = [];
        $structure->relations = [
            'Thread' => [
                'entity'     => 'XF:Thread',
                'type'       => self::TO_ONE,
                'conditions' => 'thread_id',
                'primary'    => true,
                'with'       => [
                    'User',
                    'Forum',
                    'Forum.Node',
                    'Forum.Node.Permissions|'.$visitor->permission_combination_id
                ]
            ],
            'NotesThread' => [
                'entity'     => 'XF:Thread',
                'type'       => self::TO_ONE,
                'conditions' => [['thread_id', '=', '$discussion_thread']],
                'primary'    => true,
                'with'       => [
                    'Forum',
                    'Forum.Node',
                    'Forum.Node.Permissions|'.$visitor->permission_combination_id
                ]
            ]
        ];

        return $structure;
    }
}
