<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\InlineMod\Thread;

use XF\InlineMod\AbstractAction;
use XF\Mvc\Entity\AbstractCollection;
use XF\Mvc\Entity\Entity;

/**
 * An inline moderation action for adding tags to threads.
 */
class AddTags extends AbstractAction
{
    /**
     * @return \XF\Phrase
     */
    public function getTitle()
    {
        return \XF::phrase('sv_modess_add_tags...');
    }

    /**
     * @param Entity $entity
     * @param array  $options
     * @param string $error
     *
     * @return bool
     */
    protected function canApplyToEntity(
        Entity $entity,
        array $options,
        &$error = null
    ) {
        /** @var \XF\Entity\Thread $thread */
        $thread = $entity;
        return $thread->canEditTags($error);
    }

    /**
     * @param Entity $entity
     * @param array  $options
     */
    protected function applyToEntity(Entity $entity, array $options)
    {
        /** @var \SV\ModeratorEssentials\XF\Entity\Thread $thread */
        $thread = $entity;

        if ($thread->discussion_type == 'redirect') {
            return;
        }

        /** @var \XF\Service\Tag\Changer $tagger */
        $tagger = $this->app()->service('XF:Tag\Changer', 'thread', $thread);

        $existingTags = $tagger->getExistingTagsByEditability();
        /** @var AbstractCollection $editableTags */
        $editableTags = $this->app()->em()->getBasicCollection(
            $existingTags['editable']
        );

        $tags = array_merge($editableTags->pluckNamed('tag'), $options['tags']);
        $tagger->setEditableTags($tags);

        if (!$tagger->hasErrors()) {
            $tagger->save();
        }
    }

    /**
     * @return array
     */
    public function getBaseOptions()
    {
        return [
            'tags' => []
        ];
    }

    /**
     * @param AbstractCollection $entities
     * @param \XF\Mvc\Controller $controller
     *
     * @return \XF\Mvc\Reply\AbstractReply
     */
    public function renderForm(
        AbstractCollection $entities,
        \XF\Mvc\Controller $controller
    ) {
        $threads = $entities;
        $total = $threads->count();

        $viewParams = [
            'threads' => $threads,
            'total'   => $total
        ];
        return $controller->view(
            'SV:Public:InlineMod\Thread\AddTags',
            'sv_modess_inline_mod_thread_add_tags',
            $viewParams
        );
    }

    /**
     * @param AbstractCollection $entities
     * @param \XF\Http\Request   $request
     *
     * @return array
     */
    public function getFormOptions(
        AbstractCollection $entities,
        \XF\Http\Request $request
    ) {
        $input = $request->filter([
            'tags' => 'str'
        ]);

        /** @var \XF\Repository\Tag $tagRepo */
        $tagRepo = $this->app()->repository('XF:Tag');
        $tags = $tagRepo->splitTagList($input['tags']);

        return [
            'tags' => $tags
        ];
    }
}
