<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\Job\Upgrade;

use XF\Job\AbstractRebuildJob;

/**
 * Updates thread notes threads with a distinct discussion type.
 */
class ThreadNotes extends AbstractRebuildJob
{
    /**
     * @param int $start
     * @param int $batch
     *
     * @return array
     */
    protected function getNextIds($start, $batch)
    {
        $db = $this->app->db();

        return $db->fetchAllColumn(
            $db->limit(
                'SELECT discussion_id
                    FROM xf_moderator_discussion
                    WHERE discussion_id > ?
                    ORDER BY discussion_id',
                $batch
            ),
            $start
        );
    }

    /**
     * @param int $id
     */
    protected function rebuildById($id)
    {
        /** @var \SV\ModeratorEssentials\Entity\ThreadNotes $notes */
        $notes = $this->app->em()->find(
            'SV\ModeratorEssentials:ThreadNotes',
            $id,
            'NotesThread'
        );
        if (!$notes || !$notes->NotesThread) {
            return;
        }

        $notes->NotesThread->fastUpdate('discussion_type', 'sv_thread_notes');
    }

    /**
     * @return \XF\Phrase
     */
    protected function getStatusType()
    {
        return \XF::phrase('sv_modess_thread_notes');
    }

    /**
     * @return bool
     */
    public function canCancel()
    {
        return false;
    }

    /**
     * @return bool
     */
    public function canTriggerByChoice()
    {
        return false;
    }
}
