<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials;

/**
 * Contains event listener callbacks.
 */
class Listener
{
    /**
     * @param \XF\Pub\App $app
     */
    public static function appPubSetup(\XF\Pub\App $app)
    {
        $container = $app->container();

        $container['sv.modEss.modLogLastModified'] = $app->fromRegistry(
            'svModEssModLogLM',
            function (\XF\Container $c) {
                /** @var \SV\ModeratorEssentials\XF\Repository\ModeratorLog $logRepo */
                $logRepo = $c['em']->getRepository('XF:ModeratorLog');
                return $logRepo->updateLastModifiedDate();
            }
        );
    }

    /**
     * @param \XF\Pub\App $app
     */
    public static function appPubStartEnd(\XF\Pub\App $app)
    {
        /** @var \SV\ModeratorEssentials\XF\Entity\User $visitor */
        $visitor = \XF::visitor();
        $session = $app->session();

        if (!$visitor->canViewModeratorLogCounts()) {
            return;
        }

        $sessionModLogCounts = $session->svModLogCounts;
        $modLogLastModified = $app->container('sv.modEss.modLogLastModified');

        if (
            ($sessionModLogCounts === null)
            || (
                ($sessionModLogCounts['lastModified'] < $modLogLastModified)
                && ($sessionModLogCounts['lastModified'] < (\XF::$time - (5 * 60)))
            )
        ) {
            /** @var \SV\ModeratorEssentials\XF\Repository\ModeratorLog $logRepo */
            $logRepo = $app->repository('XF:ModeratorLog');
            $logRepo->rebuildSessionLogCounts();
        }
    }

    /**
     * @param \XF\Service\User\ContentChange $changeService
     * @param array                          $updates
     */
    public static function userContentChangeInit(
        \XF\Service\User\ContentChange $changeService,
        array &$updates
    ) {
        $updates['xf_moderator_discussion'] = [
            ['user_id'],
            ['content_user_id', 'content_username']
        ];
    }

    /**
     * @param \XF\Service\User\DeleteCleanUp $deleteService
     * @param array                          $deletes
     */
    public static function userDeleteCleanInit(
        \XF\Service\User\DeleteCleanUp $deleteService,
        array &$deletes
    ) {
        $deletes['modess_modlog_preferences'] = 'user_id = ?';
    }
}
