<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\Entity;

use SV\ModeratorEssentials\Globals;

use XF\Mvc\Entity\Structure;

/**
 * Extends \XF\Entity\Thread
 */
class Thread extends XFCP_Thread
{
    /**
     * @return bool
     */
    public function canViewDeletedPosts()
    {
        $canViewDeletedPosts = parent::canViewDeletedPosts();

        if (!$canViewDeletedPosts && Globals::$checkPlaceholderVisibility) {
            return $this->canViewDeletedPostPlaceholders();
        }

        return $canViewDeletedPosts;
    }

    /**
     * @return bool
     */
    public function canViewDeletedPostPlaceholders()
    {
        $visitor = \XF::visitor();
        return $visitor->hasNodePermission(
            $this->node_id,
            'viewPostPlaceholders'
        );
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canCreateNotes(&$error = null)
    {
        if ($this->discussion_type == 'sv_thread_notes') {
            $error = \XF::phraseDeferred(
                'sv_modess_you_may_not_create_notes_for_this_thread'
            );
            return false;
        }

        /** @var \SV\ModeratorEssentials\XF\Entity\User $visitor */
        $visitor = \XF::visitor();
        if (!$visitor->canViewThreadNotes($error)) {
            return false;
        }

        return $this->Notes ? false : true;
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function hasViewableNotes(&$error = null)
    {
        if ($this->discussion_type == 'sv_thread_notes') {
            $error = \XF::phraseDeferred(
                'sv_modess_you_may_not_create_notes_for_this_thread'
            );
            return false;
        }

        /** @var \SV\ModeratorEssentials\XF\Entity\User $visitor */
        $visitor = \XF::visitor();
        if (!$visitor->canViewThreadNotes($error)) {
            return false;
        }

        if (!$this->Notes) {
            return false;
        }

        return $this->Notes->canView($error);
    }

    /**
     * @param Structure $structure
     *
     * @return Structure
     */
    public static function getStructure(Structure $structure)
    {
        $structure = parent::getStructure($structure);

        $structure->relations['Notes'] = [
            'entity'        => 'SV\ModeratorEssentials:ThreadNotes',
            'type'          => self::TO_ONE,
            'conditions'    => 'thread_id',
            'with'          => ['NotesThread'],
            'cascadeDelete' => true
        ];

        return $structure;
    }
}
