<?php

namespace SV\ModeratorEssentials\XF\Entity;

/**
 * Extends \XF\Entity\User
 */
class User extends XFCP_User
{
    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewModeratorPanel(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!\XF::options()->modessRequireAccessPermission &&
            $this->is_moderator)
        {
            return true;
        }

        return $this->hasPermission('general', 'modess_access');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewModeratorLog(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'canViewModLogCounts');
    }

    /**
     * @return bool
     */
    public function canViewModeratorLogCounts()
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'canViewModLogCounts');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canSearchIps(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'modess_IpSearch');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewBannedUserList(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'modess_viewBannedUsers');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canManageTags(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'modess_manageTags');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canManageReplyBans(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        return $this->hasPermission('general', 'modess_manageReplyBans');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canRevertMessageEdits(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        if ($this->is_super_admin) {
            return false;
        }

        if (!$this->app()->options()->editHistory['enabled']) {
            return false;
        }

        $visitor = \XF::visitor();
        return $visitor->hasPermission('general', 'modess_revertEditHistory');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewAllDeletedPosts(/** @noinspection PhpUnusedParameterInspection */&$error = null)
    {
        $visitor = \XF::visitor();
        return $visitor->hasPermission('general', 'modess_seealldeleted');
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewThreadNotes(&$error = null)
    {
        if (!$this->app()->options()->mod_discuss_node) {
            $error = \XF::phraseDeferred('sv_modess_thread_notes_disabled');
            return false;
        }

        if (!$this->canViewModeratorPanel()) {
            return false;
        }

        if (!$this->hasPermission('general', 'canModeratorDiscussion')) {
            return false;
        }

        return true;
    }

    /**
     * @param string $error
     *
     * @return bool
     */
    public function canViewModeratorLogDiscussions(&$error = null)
    {
        if (!$this->app()->options()->modess_action_discussion_node) {
            $error = \XF::phraseDeferred('sv_modess_log_discussion_disabled');
            return false;
        }

        if (!$this->is_moderator) {
            return false;
        }

        return true;
    }
}
