<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\ModeratorLog;

use SV\ModeratorEssentials\ModeratorLog\PanelInterface;

use XF\Entity\ModeratorLog;

/**
 * Extends \XF\ModeratorLog\Thread
 */
class Thread extends XFCP_Thread implements PanelInterface
{
    /**
     * @return bool
     */
    public function canViewLogs()
    {
        return true;
    }

    /**
     * @param ModeratorLog $log
     * @param string       $error
     *
     * @return bool
     */
    public function canViewLog(ModeratorLog $log, &$error = null)
    {
        /** @var \SV\ModeratorEssentials\XF\Entity\ModeratorLog $log */
        $action = $log->action;
        if (!in_array($action, $this->getActions())) {
            return false;
        }

        if (!$log->Content) {
            return false;
        }

        /** @var \XF\Entity\Thread $thread */
        $thread = $log->Content;
        /** @var \SV\ModeratorEssentials\XF\Entity\Forum $forum */
        $forum = $thread->Forum;
        return $forum->canViewModeratorLogEntries();
    }

    /**
     * @return bool
     */
    public function requiresHydration()
    {
        return true;
    }

    /**
     * @return array
     */
    public function getActions()
    {
        return [
            'approve',
            'custom_fields_edit',
            'delete_hard',
            'delete_soft',
            'edit',
            'lock',
            'merge_target',
            'move',
            'poll_add',
            'poll_create',
            'poll_delete',
            'poll_edit',
            'post_copy_source',
            'post_copy_target',
            'post_copy_target_existing',
            'post_move_source',
            'post_move_target',
            'post_move_target_existing',
            'prefix',
            'reply_ban',
            'reply_ban_delete',
            'stick',
            'title',
            'unapprove',
            'undelete',
            'unlock',
            'unstick'
        ];
    }

    /**
     * @return array
     */
    public function getEntityWith()
    {
        $with = parent::getEntityWith();

        $with[] = 'Forum';
        $visitor = \XF::visitor();
        $with[] = 'Forum.Node.Permissions|'.$visitor->permission_combination_id;

        return $with;
    }
}
