<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\Pub\Controller;

use XF\Entity\Forum;
use XF\Entity\Thread as ThreadEntity;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

/**
 * Extends \XF\Pub\Controller\Thread
 */
class Thread extends XFCP_Thread
{
    /**
     * @param ParameterBag $params
     *
     * @return \XF\Mvc\Reply\AbstractReply
     */
    public function actionIndex(ParameterBag $params)
    {
        $reply = parent::actionIndex($params);

        if ($reply instanceof \XF\Mvc\Reply\View) {
            /** @var \XF\Mvc\Reply\View $reply */

            /** @var \SV\ModeratorEssentials\XF\Entity\Thread $thread */
            $thread = $reply->getParam('thread');
            /** @var \SV\ModeratorEssentials\XF\Entity\User $visitor */
            $visitor = \XF::visitor();

            if ($visitor->canViewThreadNotes()) {
                if ($thread->discussion_type == 'sv_thread_notes') {
                    /** @var \SV\ModeratorEssentials\Repository\ThreadNotes $notesRepo */
                    $notesRepo = $this->repository('SV\ModeratorEssentials:ThreadNotes');
                    /** @var \SV\ModeratorEssentials\Entity\ThreadNotes $notes */
                    $notes = $notesRepo->findNotesForNotesThread($thread)->fetchOne();
                } else {
                    $notes = $thread->Notes;
                }

                if ($notes && $notes->canView()) {
                    $reply->setParam('notes', $notes);
                }
            }

            if (
                ($thread->discussion_type == 'modess_action_discussion')
                && $visitor->canViewModeratorLogDiscussions()
            ) {
                /** @var \SV\ModeratorEssentials\XF\Repository\ModeratorLog $modLogRepo */
                $modLogRepo = $this->repository('XF:ModeratorLog');
                /** @var \SV\ModeratorEssentials\XF\Entity\ModeratorLog $modLog */
                $modLog = $modLogRepo->findLogForLogDiscussion($thread)->fetchOne();

                if ($modLog && $modLog->canView()) {
                    $reply->setParam('moderatorLog', $modLog);
                }
            }
        }

        return $reply;
    }

    /**
     * @param ParameterBag $params
     *
     * @return \XF\Mvc\Reply\AbstractReply
     */
    public function actionNotes(ParameterBag $params)
    {
        /** @var \SV\ModeratorEssentials\XF\Entity\Thread $thread */
        $thread = $this->assertViewableThread($params->thread_id, ['Notes']);

        if ($thread->Notes) {
            if (!$thread->hasViewableNotes($error)) {
                return $this->noPermission($error);
            }

            $notes = $thread->Notes;
        } else {
            if (!$thread->canCreateNotes($error)) {
                return $this->noPermission($error);
            }

            /** @var \SV\ModeratorEssentials\Repository\ThreadNotes $notesRepo */
            $notesRepo = $this->repository('SV\ModeratorEssentials:ThreadNotes');
            $forum = $notesRepo->getNotesForum();
            if (!$forum) {
                return $this->error(\XF::phrase('requested_forum_not_found'));
            }

            $creator = $this->setupNotesCreation(
                $thread,
                $forum,
                \XF::visitor()
            );
            if (!$creator->validate($errors)) {
                return $this->error($errors);
            }

            /** @var \SV\ModeratorEssentials\Entity\ThreadNotes $notes */
            $notes = $creator->save();
            $this->finalizeNotesCreation($creator);
        }

        return $this->redirect($this->buildLink('threads', $notes->NotesThread));
    }

    /**
     * @param ThreadEntity $thread
     * @param Forum        $forum
     * @param User         $user
     *
     * @return \SV\ModeratorEssentials\Service\ThreadNotes\Creator
     */
    protected function setupNotesCreation(
        ThreadEntity $thread,
        Forum $forum,
        User $user
    ) {
        /** @var \SV\ModeratorEssentials\Service\ThreadNotes\Creator $creator */
        $creator = $this->service(
            'SV\ModeratorEssentials:ThreadNotes\Creator',
            $thread,
            $forum,
            $user
        );

        return $creator;
    }

    /**
     * @param \SV\ModeratorEssentials\Service\ThreadNotes\Creator $creator
     */
    protected function finalizeNotesCreation(
        \SV\ModeratorEssentials\Service\ThreadNotes\Creator $creator
    ) {
        $creator->sendNotifications();
    }
}
