<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\Repository;

use XF\Entity\Forum;
use XF\Mvc\Entity\Finder;

/**
 * Extends \XF\Repository\Moderator
 */
class Moderator extends XFCP_Moderator
{
    /**
     * @param Forum $forum
     *
     * @return \XF\Mvc\Entity\AbstractCollection
     */
    public function getForumModeratorsForList(Forum $forum)
    {
        $nodeIds = \XF\Util\Arr::arrayColumn(
            $forum->getBreadcrumbs(),
            'node_id'
        );

        /** @var Finder $modFinder */
        $modFinder = $this->finder('XF:ModeratorContent')
            ->where('content_type', 'node')
            ->where('content_id', $nodeIds);
        $this->applyModeratorListOptions($modFinder);
        /** @var \XF\Mvc\Entity\AbstractCollection $moderators */
        $moderators = $modFinder->fetch()->pluckNamed('User', 'user_id');

        if ($this->options()->modess_include_super_forum_moderators) {
            /** @var Finder $modFinder */
            $modFinder = $this->finder('XF:Moderator')
                ->where('is_super_moderator', true);
            $this->applyModeratorListOptions($modFinder);
            $moderators = $moderators->merge(
                $modFinder->fetch()->pluckNamed('User', 'user_id')
            );
        }

        return $moderators;
    }

    /**
     * @param Finder $modFinder
     */
    public function applyModeratorListOptions(Finder $modFinder)
    {
        $options = $this->options();

        $modFinder->with(['User', 'User.Profile', 'User.Privacy']);

        if ($options->modess_exclude_non_staff_forum_moderators) {
            $modFinder->where('User.is_staff', true);
        }

        switch ($options->modess_show_forum_moderators_order) {
            case 'username_desc':
                $modFinder->order('User.username', 'desc');
                break;

            case 'last_activity':
                $modFinder->order('User.last_activity', 'desc');
                break;

            case 'username':
            default:
                $modFinder->order('User.username');
                break;
        }
    }
}
