<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\Service\User;

/**
 * Extends \XF\Service\User\Registration
 */
class Registration extends XFCP_Registration
{
    /**
     * @return \XF\Entity\User
     */
    protected function _save()
    {
        $user = parent::_save();

        $options = $this->app->options();
        if (
            $options->registrationSetup['requireDob']
            && $options->modess_ban_underage
        ) {
            $profile = $user->Profile;

            $birthday = $profile->getBirthday(true);
            /** @var \DateTime $birthdate */
            $birthdate = $birthday['timeStamp'];

            $gracePeriod = $options->modess_ban_underage_grace_days;
            if ($gracePeriod) {
                $interval = \DateInterval::createFromDateString(
                    "{$gracePeriod} days"
                );
                $birthdate->add($interval);
            }

            $age = $profile->calculateAge(
                $birthdate->format('Y'),
                $birthdate->format('m'),
                $birthdate->format('d')
            );
            $minimumAge = max(0, intval($options->modess_ban_underage_min_age));

            if ($age < $minimumAge) {
                $endYear = ($profile->dob_year + $minimumAge);
                $endMonth = $profile->dob_month;
                $endDay = $profile->dob_day;

                $endDate = strtotime("{$endYear}-{$endMonth}-{$endDay}");
                $reason = $options->modess_ban_underage_ban_reason;

                /** @var \XF\Repository\Banning $banRepo */
                $banRepo = $this->app->repository('XF:Banning');
                $banRepo->banUser($user, $endDate, $reason, $error, $user);
            }
        }

        return $user;
    }
}
