<?php

/*
 * This file is part of a XenForo add-on.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SV\ModeratorEssentials\XF\Service\User;

use XF\Entity\Warning;

/**
 * Extends \XF\Service\User\Warn
 */
class Warn extends XFCP_Warn
{
    /**
     * @return array
     */
    protected function _validate()
    {
        if (
            ($this->warning->warning_definition_id == 0)
            && $this->app->options()->modess_limit_custom_warnings_to_admins
            && !$this->warningBy->is_admin
        ) {
            $errors = [];
            $errors['warning_definition_id'] = \XF::phrase(
                'sv_modess_please_select_a_valid_warning_type'
            );
            return $errors;
        }

        return parent::_validate();
    }

    /**
     * @param Warning $warning
     *
     * @return \XF\Service\Conversation\Creator
     */
    protected function setupConversation(Warning $warning)
    {
        $starter = $this->app->options()->modEss_warning_conversation_starter;
        if ($starter['enabled'] && $starter['username']) {
            $starter = \XF::em()->findOne(
                'XF:User',
                ['username' => $starter['username']]
            );
        } else {
            $starter = null;
        }

        if ($starter) {
            $warningBy = $this->warningBy;
            $this->warningBy = $starter;
        }

        $creator = parent::setupConversation($warning);

        if ($starter) {
            $this->warningBy = $warningBy;
        }

        return $creator;
    }
}
